#
# spec file for package perl-Net-AMQP-RabbitMQ
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-AMQP-RabbitMQ
Name:           perl-Net-AMQP-RabbitMQ
Version:        2.40014
Release:        1.1
#Upstream: MPL
License:        MPL-1.1
Summary:        Interact with RabbitMQ over AMQP using librabbitmq
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MS/MSTEMLE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Math::Int64) >= 0.34
Requires:       perl(Math::Int64) >= 0.34
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  openssl-devel
# MANUAL END

%description
'Net::AMQP::RabbitMQ' provides a simple wrapper around the librabbitmq
library that allows connecting, declaring exchanges and queues, binding and
unbinding queues, publishing, consuming and receiving events.

Error handling in this module is primarily achieve by 'Perl_croak' (die).
You should be making good use of 'eval' around these methods to ensure that
you appropriately catch the errors.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
# MANUAL no testing (needs network)
#make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md SECURITY.md
%license LICENSE LICENSE-MIT LICENSE-MPL-1.1

%changelog
* Thu Dec 12 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.40014
  see /usr/share/doc/packages/perl-Net-AMQP-RabbitMQ/Changes
  2.40014 - 2024-11-09
  - Added `confirm_select()` to put a channel into `confirm.select` mode.
  - Added `publisher_confirm_wait()` to wait for publisher confirms.
  2.40013 - 2024-10-13
  - Added a `Containerfile` to test unstable Debian builds in podman.
  - Fixed gcc-14-related build issues with a number of Linux distributions.
  - Resolved duplicate library warnings in macOS
* Thu Jul  4 2024 Tina Müller <tina.mueller@suse.com>
- updated to 2.40012
  see /usr/share/doc/packages/perl-Net-AMQP-RabbitMQ/Changes
  2.40012 - 2024-07-03
  - Updated to remove deprecated ssl_init functionality
  - Updated all tests to make them skip tests which use RMQ when RMQ isn't available
  - Lots of formatting changes
  - Updated documentation to reflect new test-specific env vars
  - Updated GitHub Actions to use latest RMQ service
  - Added a test for the purge function.
  2.40011 - 2024-06-22
  - Updated `ppport.h`
  - Fixed a problem where the SSL port defaulted to 5672 incorrectly.
  - Updated tests so they let the `RabbitMQ.xs` defaults to play a role.
  - We're now friendly to folks who want to use Carton when contributing.
  - Discontinuing use of Vagrant for licensing reasons
  - Updating `rabbitmq-c` to `v0.14.0`
  - Discontinuing use of CloudAMQP hard-coded in tests for vendor security reasons
  2.40010 - 2022-06-11
  - Fixed SSL tests
* Thu Aug 25 2022 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 2.40010
  see /usr/share/doc/packages/perl-Net-AMQP-RabbitMQ/Changes
* Sun Oct 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.40009
  see /usr/share/doc/packages/perl-Net-AMQP-RabbitMQ/Changes
  2.40009 - 2021-10-23
  - Fixed a process where subprocess closed the parent process's connection - fixes #202
  - Changed over to GitHub Actions from TravisCI
  - Added support for librabbitmq-c's RPC timeout functionality. - fixes #206
  - Updated to use the latest rabbitmq-c version.
  - Merged #201, which allows setting `client_properties` in connect.
  - Merged #200, which fixes minor document typos - fixes #199
  - Merged #198, which adds minor documentation clarification - fixes #61
* Wed Oct 21 2020 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 2.40008
  see /usr/share/doc/packages/perl-Net-AMQP-RabbitMQ/Changes
  2.40008 - 2020-09-30
  - Merged #195, to update Sectigo CA -  fixes #194
* Wed Sep 30 2020 Frank Schreiner <FSchreiner@suse.com>
- updated license to MPL-1.1
* Wed May 27 2020 Frank Schreiner <FSchreiner@suse.com>
- fixed license
* Wed May  6 2020 Frank Schreiner <FSchreiner@suse.com>
- intial version 2.40007
